==> jc-1.4.0.tar.gz: soot/jimple/parser/node/APrivateModifier.h <==
// public final class soot.jimple.parser.node.APrivateModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7cb639461d0b0211 soot_jimple_parser_node_APrivateModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_APrivateModifier_H_
#define _JC_soot_jimple_parser_node_APrivateModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TPrivate$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$sub_refs	_jc_soot_jimple_parser_node_APrivateModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs	_jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$refs	_jc_soot_jimple_parser_node_APrivateModifier$refs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$nonrefs	_jc_soot_jimple_parser_node_APrivateModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$object	_jc_soot_jimple_parser_node_APrivateModifier$object;

typedef const struct _jc_soot_jimple_parser_node_APrivateModifier$vmethods	_jc_soot_jimple_parser_node_APrivateModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_APrivateModifier$vtable	_jc_soot_jimple_parser_node_APrivateModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_APrivateModifier$vtype	_jc_soot_jimple_parser_node_APrivateModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$_init$1b6e45091d0a6fa9(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_TPrivate$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_APrivateModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);
extern struct _jc_soot_jimple_parser_node_TPrivate$object *_jc_soot_jimple_parser_node_APrivateModifier$method$getPrivate$ca85ce0f4489a016(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$setPrivate$98c618f96eb56b5f(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_TPrivate$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_APrivateModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$getPrivate$ca85ce0f4489a016;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$setPrivate$98c618f96eb56b5f;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_APrivateModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);
	struct _jc_soot_jimple_parser_node_TPrivate$object	*(*getPrivate$ca85ce0f4489a016)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPrivate$98c618f96eb56b5f)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_TPrivate$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_APrivateModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_APrivateModifier$vmethods	soot_jimple_parser_node_APrivateModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_APrivateModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_APrivateModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APrivateModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TPrivate$object	*__5fprivate__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_APrivateModifier$refs {
    _jc_soot_jimple_parser_node_APrivateModifier$sub_refs	soot_jimple_parser_node_APrivateModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_APrivateModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs	soot_jimple_parser_node_APrivateModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_APrivateModifier$object {
	_jc_soot_jimple_parser_node_APrivateModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_APrivateModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_APrivateModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_APrivateModifier$vtype _jc_soot_jimple_parser_node_APrivateModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_APrivateModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_APrivateModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_APrivateModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/APrivateModifier.h <==
// public final class soot.jimple.parser.node.APrivateModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7cb639461d0b0211 soot_jimple_parser_node_APrivateModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_APrivateModifier_H_
#define _JC_soot_jimple_parser_node_APrivateModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TPrivate$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$sub_refs	_jc_soot_jimple_parser_node_APrivateModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs	_jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$refs	_jc_soot_jimple_parser_node_APrivateModifier$refs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$nonrefs	_jc_soot_jimple_parser_node_APrivateModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_APrivateModifier$object	_jc_soot_jimple_parser_node_APrivateModifier$object;

typedef const struct _jc_soot_jimple_parser_node_APrivateModifier$vmethods	_jc_soot_jimple_parser_node_APrivateModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_APrivateModifier$vtable	_jc_soot_jimple_parser_node_APrivateModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_APrivateModifier$vtype	_jc_soot_jimple_parser_node_APrivateModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$_init$1b6e45091d0a6fa9(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_TPrivate$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_APrivateModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TPrivate$object *_jc_soot_jimple_parser_node_APrivateModifier$method$getPrivate$ca85ce0f4489a016(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_APrivateModifier$method$setPrivate$98c618f96eb56b5f(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_TPrivate$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_APrivateModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$getPrivate$ca85ce0f4489a016;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$setPrivate$98c618f96eb56b5f;
extern _jc_method _jc_soot_jimple_parser_node_APrivateModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_APrivateModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TPrivate$object	*(*getPrivate$ca85ce0f4489a016)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPrivate$98c618f96eb56b5f)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *, struct _jc_soot_jimple_parser_node_TPrivate$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_APrivateModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_APrivateModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_APrivateModifier$vmethods	soot_jimple_parser_node_APrivateModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_APrivateModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_APrivateModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APrivateModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TPrivate$object	*__5fprivate__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_APrivateModifier$refs {
    _jc_soot_jimple_parser_node_APrivateModifier$sub_refs	soot_jimple_parser_node_APrivateModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_APrivateModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_APrivateModifier$sub_nonrefs	soot_jimple_parser_node_APrivateModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_APrivateModifier$object {
	_jc_soot_jimple_parser_node_APrivateModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_APrivateModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_APrivateModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_APrivateModifier$vtype _jc_soot_jimple_parser_node_APrivateModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_APrivateModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_APrivateModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_APrivateModifier_H_ */
